Description Usage Arguments Details See Also Examples
print method for class "SCBand".
1 2 |
object |
an object of class |
... |
for compatibility with the generic |
The function print.SCBand concisely displays the information of an object of class "SCBand". More precisely it shows the
data range, bandwidth used in local polynomial estimation, and key information on SCB and statistical tests.
1 2 3 4 5 6 7 8 9 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.